@@ -1,5 +1,5 @@
 package List::Compare::Base::_Engine;
-$VERSION = 0.43;
+$VERSION = 0.44;
 # Holds subroutines used within
 # List::Compare::Base::Accelerated and List::Compare::Functional
 use Carp;
@@ -53,17 +53,15 @@ sub _unique_all_engine {
 sub _complement_all_engine {
     my ($aref, $unsortflag) = @_;
     my ($unionref, $seenref) = _calculate_union_seen_only($aref);
-    my %seen = %{$seenref};
     my @union = $unsortflag ? keys %{$unionref} : sort(keys %{$unionref});
 
     # Calculate @xcomplement
     # Inputs:  $aref @union %seen
     my (@xcomplement);
     for (my $i = 0; $i <= $#{$aref}; $i++) {
-        my %seenthis = %{$seen{$i}};
         my @complementthis = ();
-        foreach (@union) {
-            push(@complementthis, $_) unless (exists $seenthis{$_});
+        foreach my $el (@union) {
+            push(@complementthis, $el) unless (exists $seenref->{$i}->{$el});
         }
         $xcomplement[$i] = \@complementthis;
     }
@@ -81,8 +79,8 @@ List::Compare::Base::_Engine - Internal use only
 
 =head1 VERSION
 
-This document refers to version 0.43 of List::Compare::Base::_Engine.
-This version was released February 12 2015.
+This document refers to version 0.44 of List::Compare::Base::_Engine.
+This version was released February 15 2015.
 
 =head1 SYNOPSIS
 
@@ -94,7 +92,7 @@ List::Compare::Functional.  They are not intended to be publicly callable.
 James E. Keenan (jkeenan@cpan.org).  When sending correspondence, please
 include 'List::Compare' or 'List-Compare' in your subject line.
 
-Creation date:  May 20, 2002.  Last modification date:  February 12 2015.
+Creation date:  May 20, 2002.  Last modification date:  February 15 2015.
 Copyright (c) 2002-15 James E. Keenan.  United States.  All rights reserved.
 This is free software and may be distributed under the same terms as Perl
 itself.
