@@ -1,5 +1,5 @@
 package List::Compare::Functional;
-$VERSION = 0.43;
+$VERSION = 0.44;
 @ISA = qw(Exporter);
 @EXPORT_OK = qw|
     get_intersection
@@ -219,17 +219,14 @@ sub _complement_engine {
     my $tested = pop(@_);
     my $seenrefsref = _calc_seen1(@_);
     my ($unionref, $seenref) = _calculate_union_seen_only($seenrefsref);
-    my %seen = %{$seenref};
-    my @union = keys %{$unionref};
 
     # Calculate %xcomplement
-    # Inputs:  $seenrefsref @union %seen
+    # Inputs:  $seenrefsref @union (keys %$unionref)
     my (%xcomplement);
     for (my $i = 0; $i <= $#{$seenrefsref}; $i++) {
-        my %seenthis = %{$seen{$i}};
         my @complementthis = ();
-        foreach (@union) {
-            push(@complementthis, $_) unless (exists $seenthis{$_});
+        foreach my $k (keys %{$unionref}) {
+            push(@complementthis, $k) unless (exists $seenref->{$i}->{$k});
         }
         $xcomplement{$i} = \@complementthis;
     }
@@ -530,8 +527,8 @@ List::Compare::Functional - Compare elements of two or more lists
 
 =head1 VERSION
 
-This document refers to version 0.43 of List::Compare::Functional.
-This version was released February 12 2015.  The first released
+This document refers to version 0.44 of List::Compare::Functional.
+This version was released February 15 2015.  The first released
 version of List::Compare::Functional was v0.21.  Its version numbers
 are set to be consistent with the other parts of the List::Compare
 distribution.
@@ -1695,7 +1692,7 @@ James E. Keenan (jkeenan@cpan.org).  When sending correspondence, please
 include 'List::Compare::Functional' or 'List-Compare-Functional' in your
 subject line.
 
-Creation date:  May 20, 2002.  Last modification date:  February 12 2015.
+Creation date:  May 20, 2002.  Last modification date:  February 15 2015.
 Copyright (c) 2002-15 James E. Keenan.  United States.  All rights reserved.
 This is free software and may be distributed under the same terms as Perl
 itself.
